@@ -89,7 +89,7 @@ size_to_string_text (guint64 bytes)
 	guint64     t_bytes;
 	const char *unit;
 	char       *result;
-	
+
 	if (bytes > 1125899906842624ull) {
 		t_bytes = (bytes * 10) / 1125899906842624ull;
 		unit = "PiB";
@@ -109,7 +109,7 @@ size_to_string_text (guint64 bytes)
 		t_bytes = bytes;
 		unit = "B";
 	}
-	
+
 	result = g_strdup_printf ("%" G_GUINT64_FORMAT ".%" G_GUINT64_FORMAT " %s", t_bytes / 10, t_bytes % 10, unit);
 
 	return result;
@@ -135,18 +135,21 @@ static void
 ncb_selection_dialog_set_label (NcbSelectionDialog *dialog,
                                 const char         *label)
 {
-	GtkWidget *entry;
-        gboolean   sensitive;
+	NcbSelectionSource type;
+	GtkWidget	  *entry;
+	gboolean	   sensitive;
 
 	entry = glade_xml_get_widget (dialog->priv->xml, "cdname_entry");
 
-        if (label != NULL) {
-                gtk_entry_set_text (GTK_ENTRY (entry), label);
-        }
+	if (label != NULL) {
+		gtk_entry_set_text (GTK_ENTRY (entry), label);
+	}
 
-        sensitive = TRUE;
-        gtk_editable_set_editable (GTK_EDITABLE (entry), sensitive);
-        gtk_widget_set_sensitive (entry, sensitive);
+	ncb_selection_get_source (dialog->priv->selection, &type, NULL);
+	sensitive = (type == NCB_SELECTION_SOURCE_BURN_FOLDER);
+
+	gtk_editable_set_editable (GTK_EDITABLE (entry), sensitive);
+	gtk_widget_set_sensitive (entry, sensitive);
 }
 
 static void
@@ -195,7 +198,6 @@ update_label (NcbSelectionDialog *dialog)
 	ncb_selection_dialog_set_label (dialog, label);
 }
 
-
 static gboolean
 update_dialog_selection (NcbSelectionDialog *dialog)
 {
@@ -389,9 +391,12 @@ update_speeds_combobox (NautilusBurnDrive *drive,
 		/* If we can't get the media type see if the drive is capable DVD */
 		if (name == NULL) {
 			gboolean is_dvd;
+			int      type;
 
-			is_dvd = (drive->type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RW_RECORDER)
-				|| (drive->type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RAM_RECORDER);
+			type = nautilus_burn_drive_get_drive_type (drive);
+
+			is_dvd = (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RW_RECORDER)
+				|| (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RAM_RECORDER);
 			if (is_dvd) {
 				name = g_strdup_printf ("CD %d\303\227, DVD %d\303\227",
 							NAUTILUS_BURN_DRIVE_CD_SPEED (write_speeds[i]),
@@ -437,11 +442,14 @@ refresh_dialog (NcbSelectionDialog *dialog)
 	combobox = glade_xml_get_widget (dialog->priv->xml, "speed_combobox");
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combobox));
 
-	g_object_set (drive, "enable-monitor", TRUE, NULL);
 	g_signal_connect (drive, "media-added", G_CALLBACK (dialog_media_added_cb), combobox);
 
 	if (drive) {
-		if (drive->type == NAUTILUS_BURN_DRIVE_TYPE_FILE) {
+		int type;
+
+		type = nautilus_burn_drive_get_drive_type (drive);
+
+		if (type == NAUTILUS_BURN_DRIVE_TYPE_FILE) {
 			gtk_list_store_clear (GTK_LIST_STORE (model));
 			gtk_widget_set_sensitive (combobox, FALSE);
 		} else {
@@ -556,7 +564,6 @@ init_dialog (NcbSelectionDialog *dialog)
 	sync_drive_selection (dialog);
 }
 
-
 static void
 selection_source_type_changed (NcbSelection       *selection,
 			       GParamSpec         *pspec,
